use std::iter::Peekable;

use roxmltree::{Children, Node};

use crate::{
    law::Content,
    paragraph::parser::{Absatz, Expect, Schlussteil, Ziffernliste},
};

#[derive(Debug)]
pub(crate) struct Liste {
    content: Vec<Content>,
}
impl Liste {
    pub(crate) fn test(n: &Node) -> bool {
        n.tag_name().name() == "liste"
    }

    pub(crate) fn parse_full(n: &mut Peekable<Children>) -> Self {
        Expect::from(n.peek().unwrap()).tag("liste");

        let mut content = Vec::new();

        let mut c = n.next().unwrap().children().peekable();

        // Parse stuff inside <liste>
        while let Some(child) = c.peek() {
            if Ziffernliste::test(child) {
                content.push(Ziffernliste::parse(c.next().unwrap()).get_content());
            } else if Schlussteil::test(child) {
                // 162 Schifffahrtsgesetz show use that a 'schlussteil' can be at the start of a list
                content.push(Content::Text(Schlussteil::parse(c.next().unwrap()).content));
            } else {
                break;
            }
        }

        // Parse stuff after <liste>, which logically still is for the list
        while let Some(child) = n.peek() {
            if Absatz::test_with_typ(child, "satz") {
                content.push(Content::Text(Absatz::parse(n.next().unwrap()).content));
            } else {
                break;
            }
        }
        Self { content }
    }

    pub(crate) fn get_content(&self) -> Content {
        Content::List(self.content.clone())
    }
}
