use std::iter::Peekable;

use roxmltree::{Children, Node};

use crate::{law::Content, paragraph::parser::Expect};

use super::{Absatz, Tr};

#[derive(Debug, PartialEq)]
pub(crate) struct Table {
    trs: Vec<Tr>,
}
impl Table {
    // TODO: Combine mandatory check in parse + optional check in test -> Expect trait?
    pub(crate) fn test(n: &Node) -> bool {
        n.tag_name().name() == "table"
    }

    pub(crate) fn parse_full(n: &mut Peekable<Children>) -> Vec<Content> {
        Expect::from(n.peek().unwrap()).tag("table");

        let mut content = Vec::new();

        let mut trs = Vec::new();

        let c = n.next().unwrap();

        // Parse table
        for child in c.children() {
            trs.push(Tr::parse(&child));
        }
        content.push(Self::get_list(&trs));

        // erltext after table belongs to table
        while let Some(child) = n.peek() {
            if Absatz::test_with_typ(child, "erltext") {
                content.push(Content::Text(Absatz::parse(n.next().unwrap()).content));
            } else {
                break;
            }
        }

        content
    }

    pub(crate) fn get_list(trs: &Vec<Tr>) -> Content {
        let mut ret = Vec::new();

        for tr in trs {
            let mut txt = String::new();
            for td in &tr.tds {
                txt.push_str(&format!("{} ", td.absatz.content));
            }

            ret.push(Content::Text(format!("- {txt}",)));
        }

        Content::List(ret)
    }
}
